// SPDX-FileCopyrightText: 2010-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes

#include "AboutDialog.h"

#include "SharedObjects/SharedObjects.h"
#include "SharedObjects/Database.h"
#include "SharedObjects/ResourceFinder.h"
#include "SharedObjects/TournamentSettings.h"

#include "shared/SharedStyles.h"
#include "shared/Urls.h"

#include "network/ServerProtocol.h"

#include "version.h"

// Qt includes
#include <QVBoxLayout>
#include <QGroupBox>
#include <QLabel>
#include <QDebug>
#include <QIcon>
#include <QDate>

AboutDialog::AboutDialog(QWidget *parent, SharedObjects *sharedObjects) : TitleDialog(parent)
{
    setWindowTitle(tr("Über Muckturnier"));
    addButtonBox(QDialogButtonBox::Ok);
    mainLayout()->setSizeConstraint(QLayout::SetFixedSize);

    QLabel *currentLabel;
    QGroupBox *currentBox;
    QVBoxLayout *currentLayout;

    const QDate compilerDate = QLocale(QStringLiteral("en_US")).toDate(
        QStringLiteral(__DATE__).simplified(), QStringLiteral("MMM d yyyy"));

    currentLayout = new QVBoxLayout;
    currentLayout->setSpacing(0);
    layout()->addLayout(currentLayout);


    // Banner
    currentLabel = new QLabel;
    currentLabel->setPixmap(QPixmap(sharedObjects->resourceFinder()->find(
                                QStringLiteral("banner.png"))));
    currentLabel->setAlignment(Qt::AlignCenter);
    currentLabel->setStyleSheet(SharedStyles::headerLogo);
    currentLabel->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
    currentLayout->addWidget(currentLabel);

    // Subtitle
    currentLabel = new QLabel(tr("Das Programm für die Turnierleitung"));
    currentLabel->setStyleSheet(SharedStyles::footerLogo);
    currentLabel->setAlignment(Qt::AlignCenter);
    currentLayout->addWidget(currentLabel);

    // Version box

    currentBox = new QGroupBox;
    currentLayout = new QVBoxLayout(currentBox);
    layout()->addWidget(currentBox);

    currentLabel = new QLabel(
          tr("<div syle=\"text-align: center;\"><b>Version %1 (%2)</b></div>").arg(
             QLatin1String(MT_VERSION), compilerDate.toString(QLatin1String("dd.MM.yyyy")))
             + QLatin1String("<div style=\"text-align: center;\"><table>")
             + tr("<tr><td>Datenbank:</td><td>Revision %1</td></tr>").arg(
                  sharedObjects->database()->dbVersion())
             + tr("<tr><td>Einstellungen:</td><td>Revision %1</td></tr>").arg(
                  sharedObjects->tournamentSettings()->version())
             + tr("<tr><td>Serverprotokoll:</td><td>Revision %1</td></tr>").arg(
                  ServerProtocol::protocolVersion)
             + QLatin1String("</table></div>"));
    currentLabel->setAlignment(Qt::AlignCenter);
    currentLabel->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    currentLabel->setOpenExternalLinks(true);
    currentLayout->addWidget(currentLabel);

    // License box

    currentBox = new QGroupBox;
    currentLayout = new QVBoxLayout(currentBox);
    layout()->addWidget(currentBox);

    currentLabel = new QLabel(
        tr("<p>Quellcode veröffentlicht unter der<br/>"
           "<a href=\"https://www.gnu.org/licenses/#GPL\">GNU General Public License (GPL)</a></p>"
           "<p>Kompiliert gegen <a href=\"https://www.qt.io/\">Qt</a> %1</p>").arg(
           QLatin1String(QT_VERSION_STR)));

    currentLabel->setAlignment(Qt::AlignCenter);
    currentLabel->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    currentLabel->setOpenExternalLinks(true);
    currentLayout->addWidget(currentLabel);

    // Author box

    currentBox = new QGroupBox;
    currentLayout = new QVBoxLayout(currentBox);
    layout()->addWidget(currentBox);

    currentLabel = new QLabel(
        tr("Copyright %1 2010–%2 Tobias Leupold").arg(
           QStringLiteral("\u00A9"), QString::number(compilerDate.year()))
           + tr("<br/>"
                "<a href=\"%1\">%1</a>").arg(Urls::homepage));
    currentLabel->setAlignment(Qt::AlignCenter);
    currentLabel->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    currentLabel->setOpenExternalLinks(true);
    currentLayout->addWidget(currentLabel);
}
