// SPDX-FileCopyrightText: 2019-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef DRAWOVERVIEWPAGE_H
#define DRAWOVERVIEWPAGE_H

// Local includes
#include "shared/OptionalPage.h"
#include "shared/Draw.h"

// Local classes
class SharedObjects;
class Settings;
class TournamentSettings;
class SearchWidget;
class SearchEngine;
class RegistrationListModel;

// Qt classes
class QLabel;
class QTableWidget;

class DrawOverviewPage : public OptionalPage
{
    Q_OBJECT

public:
    explicit DrawOverviewPage(QWidget *parent, SharedObjects *sharedObjects,
                              RegistrationListModel *listModel, bool drawAdjustmentNeeded);
    void updateDraw(bool ownChange, const QString &target, bool deleted);

public slots:
    void resetSearch();
    void drawAdjustmentNeeded(bool state);

signals:
    void showAdjustDrawDialog();

public slots:
    bool closePage();

private slots:
    void updateSearch(const QString &searchText);

private: // Functions
    void scrollTo(const QString &target);

private: // Variables
    Settings *m_settings;
    TournamentSettings *m_tournamentSettings;
    SearchEngine *m_searchEngine;
    RegistrationListModel *m_listModel;

    QLabel *m_uncompletedTablesLabel;
    QLabel *m_noDraw;

    QLabel *m_isSearch;
    QTableWidget *m_draw;
    QLabel *m_adjustmentLabel;
    SearchWidget *m_searchWidget;

    QVector<QString> m_searchText;

};

#endif // DRAWOVERVIEWPAGE_H
