// SPDX-FileCopyrightText: 2019-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef DRAWPOPUP_H
#define DRAWPOPUP_H

// Local includes
#include "shared/SelectionPopup.h"
#include "shared/Draw.h"

// Qt classes
class QSpinBox;
class QRadioButton;
class QLabel;
class QPushButton;

class DrawPopup : public SelectionPopup
{
    Q_OBJECT

public:
    explicit DrawPopup(QWidget *parent, const Draw::Settings *drawSettings,
                       const QVector<int> &assignedPair1Tables,
                       const QVector<int> &assignedPair2Tables);
    void show(Draw::Seat seat, bool allRoundsFinished, bool isSinglePlayer,
              const QPoint &position);
    Draw::Seat seat() const;
    void setPairMode(bool state);
    QVector<Draw::Seat> completeDraw(int seats) const;
    bool isSeatTaken(const Draw::Seat &seat) const;

public Q_SLOTS:
    void updateFirstFreeTable();
    void checkSelection();

private Q_SLOTS:
    void selectFirstFreeSeat();
    void drawSeat();
    void confirmDelete();

private: // Functions
    int findFirstGap(const QVector<int> *list) const;
    void selectSeat(const Draw::Seat &seat);
    Draw::Seat getRandomSeat() const;

private: // Variables
    const Draw::Settings *m_drawSettings;
    const QVector<int> *m_assignedPair1Tables;
    const QVector<int> *m_assignedPair2Tables;

    int m_assignmentsPerPair;
    Draw::Seat m_firstFreeSeat;
    QVector<Draw::Seat> m_drawableSeats;
    bool m_drawingPossible = false;
    bool m_allRoundsFinished;

    QWidget *m_main;
    QWidget *m_selection;
    QLabel *m_isSinglePlayer;
    QSpinBox *m_table;
    QRadioButton *m_pair1;
    QRadioButton *m_pair2;
    QLabel *m_taken;
    QLabel *m_beyondLimit;
    QPushButton *m_save;
    QPushButton *m_delete;
    QPushButton *m_newDraw;

};

#endif // DRAWPOPUP_H
