// SPDX-FileCopyrightText: 2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef MARKERSLISTMODEL_H
#define MARKERSLISTMODEL_H

// Local includes
#include "shared/Markers.h"

// Qt includes
#include <QAbstractTableModel>
#include <QIcon>

// Local classes
class SharedObjects;
class Database;
class StringTools;

class MarkersListModel : public QAbstractTableModel
{
    Q_OBJECT

public:
    explicit MarkersListModel(QObject *parent, SharedObjects *sharedObjects);
    int rowCount(const QModelIndex &index = QModelIndex()) const override;
    int columnCount(const QModelIndex &index = QModelIndex()) const override;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
    QVariant headerData(int section, Qt::Orientation orientation,
                        int role = Qt::DisplayRole) const override;

    void updateMarkersCounts(const QHash<int, int> &count);
    void clear();
    void refresh();
    void toggleVisible(int row);
    void showOnly(int row);
    bool isVisible(int id) const;
    bool allVisible() const;
    const Markers::Marker &data(int row) const;
    const QVector<Markers::Marker> &markers() const;
    const QString &unmarkedName() const;
    bool isUnmarkedName(const QString &name) const;
    QString nameIsPresent(const QString &name) const;
    bool containsName(const QString &name) const;

Q_SIGNALS:
    void visibilityChanged();

private: // Variables
    Database *m_db;
    StringTools *m_stringTools;
    const QIcon m_unused;
    const QIcon m_visible;
    const QIcon m_hidden;
    const int m_columnCount;

    int m_rowCount = 0;
    const QString *m_unmarkedName = nullptr;
    QVector<Markers::Marker> m_markers;
    QHash<int, bool> m_isVisible;
    QHash<int, int> m_markersCounts;

};

#endif // MARKERSLISTMODEL_H
