// SPDX-FileCopyrightText: 2019-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "MarkersPopup.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QPushButton>
#include <QVariant>

// C++ includes
#include <functional>

MarkersPopup::MarkersPopup(QWidget *parent, const QVector<Markers::Marker> &markers)
    : SelectionPopup(parent),
      m_markers(&markers)
{
}

void MarkersPopup::show(int currentMarker, const QPoint &position)
{
    m_currentMarker = currentMarker;

    if (m_markersCount == 1) {
        reject();
        return;
    }

    updateVisibility();

    if (position == QPoint(-1, -1)) {
        SelectionPopup::show();
    } else {
        SelectionPopup::show(position);
    }
}

void MarkersPopup::updateMarkers()
{
    m_markersCount = m_markers->count();

    auto *widget = new QWidget;
    auto *layout = new QVBoxLayout(widget);
    layout->setSpacing(0);

    for (const Markers::Marker &marker : *m_markers) {
        auto *button = textButton(marker.name);
        button->setStyleSheet(QStringLiteral("color:") + marker.color.name());
        button->setProperty("id", QVariant(marker.id));
        layout->addWidget(button);
        connect(button, &QPushButton::clicked,
                std::bind(&MarkersPopup::markerSelected, this, button));
    }

    const auto wasVisible = isVisible();

    widget->show();
    widget->adjustSize();
    setScrollWidget(widget);

    if (wasVisible) {
        updateVisibility();
        show(m_currentMarker, geometry().topLeft());
    }
}

void MarkersPopup::updateVisibility()
{
    for (auto *button : findChildren<QPushButton *>()) {
        button->setVisible(button->property("id").toInt() != m_currentMarker);
    }
}

void MarkersPopup::markerSelected(QPushButton *button)
{
    m_markerId = button->property("id").toInt();
    m_markerName = m_markerId != 0 ? button->text() : QString();
    accept();
}

QString MarkersPopup::markerName() const
{
    return m_markerName;
}

int MarkersPopup::markerId() const
{
    return m_markerId;
}
