// SPDX-FileCopyrightText: 2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef REGISTRATIONLISTVIEW_H
#define REGISTRATIONLISTVIEW_H

// Local includes
#include "shared/RegistrationColumns.h"

// Qt includes
#include <QTableView>
#include <QPointer>

// Local classes
class SharedObjects;
class RegistrationListModel;
class PlayersEditor;

class RegistrationListView : public QTableView
{
    Q_OBJECT

public:
    explicit RegistrationListView(SharedObjects *sharedObjects, QWidget *parent = nullptr);
    void setModel(QAbstractItemModel *model) override;
    void selectName(const QString &name, int originalVisibleRow = -1);
    void selectRow(int row, int originalVisibleRow);
    const QString &selectedName() const;
    void deselectRow();
    int selectedRow() const;
    int selectedVisibleRow() const;
    int visibleRow(int row) const;
    bool isEditing() const;
    void saveEditorState();
    void abortEdit();
    void restoreEditorState();

Q_SIGNALS:
    void rowHovered(int row);
    void rowSelected(int row);
    void requestPopup(RegistrationColumns::Column column);

public Q_SLOTS:
    void editorCreated(QWidget *editor, const QString &name);
    void indexClicked(const QModelIndex &index);
    void editCurrentName();

protected:
    void mouseMoveEvent(QMouseEvent *event) override;
    bool viewportEvent(QEvent *event) override;
    void mousePressEvent(QMouseEvent *event) override;

private Q_SLOTS:
    void updateHoveredRow(int row);

private: // Variables
    const int m_columnCount;
    RegistrationListModel *m_model;
    Qt::MouseButton m_lastPressedButton;
    int m_lastHoveredRow = -1;
    int m_hoveredRow = -1;
    int m_lastSelectedRow = -1;
    int m_selectedRow = -1;
    QPointer<PlayersEditor> m_editor;
    QString m_lastEditedName;
    QString m_selectedName;

    // Editor state cache
    QString m_enteredText;
    int m_selectionStart = -1;
    int m_selectionLength = -1;
    int m_cursorPosition = -1;

};

#endif // REGISTRATIONLISTVIEW_H
