// SPDX-FileCopyrightText: 2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "MarginSpinBox.h"

// Qt includes
#include <QLabel>
#include <QHBoxLayout>
#include <QFontMetrics>
#include <QSpinBox>

// C++ includes
#include <functional>

MarginSpinBox::MarginSpinBox(Qt::Alignment pos, QWidget *parent) : QWidget(parent)
{
    auto *layout = new QHBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 0);

    int labelWidth = 0;
    const QFontMetrics fontMetrics(font());
    for (const auto &text : { tr("Oben:"), tr("Rechts:"), tr("Unten:"), tr("Links:") }) {
        const auto width = fontMetrics.boundingRect(text).width();
        if (width > labelWidth) {
            labelWidth = width;
        }
    }

    QString text;
    Q_ASSERT(pos == Qt::AlignTop || pos == Qt::AlignRight
             || pos ==  Qt::AlignBottom || pos == Qt::AlignLeft);
    if (pos == Qt::AlignTop) {
        text = tr("Oben:");
    } else if (pos == Qt::AlignRight) {
        text = tr("Rechts:");
    } else if (pos == Qt::AlignBottom) {
        text = tr("Unten:");
    } else if (pos == Qt::AlignLeft) {
        text = tr("Links:");
    }

    auto *label = new QLabel(text);
    label->setMinimumWidth(labelWidth);
    label->setMaximumWidth(labelWidth);

    layout->addWidget(label);

    m_margin = new QSpinBox;
    connect(m_margin, &QSpinBox::valueChanged,
            std::bind(&MarginSpinBox::valueChanged, this, pos, std::placeholders::_1));
    m_margin->setMinimum(0);
    m_margin->setMaximum(999);
    m_margin->setValue(0);
    layout->addWidget(m_margin);
}

void MarginSpinBox::setValue(int value)
{
    m_margin->setValue(value);
}
