// SPDX-FileCopyrightText: 2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef RESIZABLELABEL_H
#define RESIZABLELABEL_H

// Qt includes
#include <QWidget>
#include <QHash>

// Local classes
class ExpandingLabel;
class QToolButton;
class QSpinBox;

// Qt classes
class QLabel;

class ResizableLabel : public QWidget
{
    Q_OBJECT

public:
    explicit ResizableLabel(QWidget *parent = nullptr);
    Qt::AlignmentFlag alignment() const;
    bool isBold() const;
    int maxHeight() const;
    int stretch() const;

Q_SIGNALS:
    void stretchFactorChanged(int factor);

public Q_SLOTS:
    void setFormattingVisible(bool state);
    void reset();
    void setText(const QString &text);
    void setBold(bool state);
    void setAlignment(Qt::AlignmentFlag alignment);
    void setMaxHeight(int height);
    void setStretch(int stretch);

private: // Variables
    QWidget *m_formatting;
    QToolButton *m_bold;
    QHash<QToolButton *, Qt::AlignmentFlag> m_alignment;
    QSpinBox *m_maxHeight;
    QSpinBox *m_stretch;
    ExpandingLabel *m_label;

};

#endif // RESIZABLELABEL_H
