// SPDX-FileCopyrightText: 2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef SCHEDULEDISPLAY_H
#define SCHEDULEDISPLAY_H

// Qt includes
#include <QDialog>
#include <QHash>

// Local classes
class Settings;
class ResizableLabel;
class MarginSpinBox;

// Qt classes
class QLabel;
class QJsonObject;
class QScreen;

class ScheduleDisplay : public QDialog
{
    Q_OBJECT

public:
    explicit ScheduleDisplay(QWidget *parent, Settings *settings);
    void showFullScreen(QScreen *screen);
    void setScheduleStarted(bool state);

public Q_SLOTS:
    void updateClock(const QString &text);
    void updateCurrentRound(int round);
    void updateNextRound(int round);
    void updateRoundTimeLeft(const QString &text);
    void updateTimeToNextRound(const QString &text);
    void updateNextRoundStart(const QString &text);

private Q_SLOTS:
    void toggleFullScreen();
    void setFormattingVisible(bool state);
    void setMargin(Qt::Alignment pos, int margin);
    void chooseColor(const QString &name);
    void saveSettings();
    void resetSettings();

private: // Functions
    void loadSettings();
    void updateColors();
    void setTimeToNextRoundText(const QString &text);

private: // Variables
    Settings *m_settings;

    QWidget *m_labelsWrapper;
    QAction *m_setFormattingVisible;
    QAction *m_toggleFullScreen;

    QHash<QString, ResizableLabel *> m_labels;
    QHash<Qt::Alignment, MarginSpinBox *> m_margins;
    QHash<Qt::Alignment, QLabel *> m_spacers;

    QHash<QString, QColor> m_colors;

    QFlags<Qt::WindowState> m_lastWindowState = Qt::WindowNoState;

    bool m_scheduleStarted = false;
    int m_currentRound = 0;
    int m_nextRound = 0;
    bool m_negativeTime = false;

};

#endif // SCHEDULEDISPLAY_H
