// SPDX-FileCopyrightText: 2018-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef STRINGTOOLS_H
#define STRINGTOOLS_H

// Qt includes
#include <QObject>
#include <QLocale>
#include <QCollator>

// C++ includes
#include <algorithm>

class StringTools : public QObject
{
    Q_OBJECT

public:
    explicit StringTools(QObject *parent, const QString *boogerSymbol);

    template<typename T>
    void sort(T &data) const
    {
        std::sort(data.begin(), data.end(), m_collator);
    }

    QString toLower(const QString &text) const;
    QString toUpper(const QString &text) const;
    void setBoogerScore(int score);
    QString boogify(int score) const;
    QString locale() const;
    QString defaultLocale() const;
    void setLocale(const QString &name);
    bool resetLocale();
    bool localeChanged() const;
    QString dateFormat() const;
    QString timeFormat() const;

private: // Variables
    const QString *m_boogerSymbol;
    QLocale m_locale;
    QCollator m_collator;
    bool m_localeChanged = false;
    int m_boogerScore;

};

#endif // STRINGTOOLS_H
