// SPDX-FileCopyrightText: 2020-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "ChecksumHelper.h"
#include "ColorHelper.h"

// Qt includes
#include <QCryptographicHash>
#include <QDebug>

static const QChar s_space = QLatin1Char(' ');

ChecksumHelper::ChecksumHelper(QObject *parent) : QObject(parent)
{
}

void ChecksumHelper::addData(const QString &data)
{
    m_data.append(data);
    m_data.append(s_space);
}

void ChecksumHelper::addData(int data)
{
    m_data.append(QString::number(data));
    m_data.append(s_space);
}

void ChecksumHelper::addData(const Markers::Marker &marker)
{
    addData(marker.id);

    // Name and color of the "unmarked" marker depend on the local settings.
    // Thus, we have to handle this one in a special way
    if (marker.id != 0) {
        addData(marker.name);
        addData(ColorHelper::colorToString(marker.color));
    } else {
        addData(QString());
        addData(ColorHelper::colorToString(QColor(0, 0, 0)));
    }

    addData(marker.sorting);
}

void ChecksumHelper::addData(const Players::Data &data)
{
    addData(data.name);
    addData(data.marker);
    addData(data.assignment);
    addData(data.disqualified);
}

void ChecksumHelper::addData(const Draw::Seat &seat)
{
    addData(seat.table);
    addData(seat.pair);
}

QString ChecksumHelper::checksum() const
{
    QCryptographicHash hash(QCryptographicHash::Md5);
    hash.addData(m_data.toUtf8());
    return QLatin1String(hash.result().toHex());
}

void ChecksumHelper::clear()
{
    m_data.clear();
}
