// SPDX-FileCopyrightText: 2020-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "DrawMapper.h"

// Qt includes
#include <QHash>

// C++ includes
#include <algorithm>

namespace DrawMapper
{

QVector<QVector<QString>> mapDraw(const QVector<Players::Data> playersData)
{
    QHash<int, QVector<QString>> draw;
    for (int i = 0; i < playersData.count(); i++) {
        const auto &seat = playersData.at(i).assignment;
        if (! draw.contains(seat.table)) {
            auto players = QVector<QString>(4);
            players[Draw::indexForPair(seat.pair)] = playersData.at(i).name;
            draw.insert(seat.table, players);
        } else {
            int index = Draw::indexForPair(seat.pair);
            if (! draw.value(seat.table).at(index).isEmpty()) {
                index++;
            }
            draw[seat.table][index] = playersData.at(i).name;
        }
    }

    QVector<QVector<QString>> sortedDraw;
    const auto tables = draw.keys();
    for (int i = 1; i <= *std::max_element(tables.begin(), tables.end()); i++) {
        if (draw.contains(i)) {
            sortedDraw.append(draw.value(i));
        } else {
            sortedDraw.append(QVector<QString>(4));
        }
    }

    return sortedDraw;
}

}
