// SPDX-FileCopyrightText: 2010-2023 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef TABLEDELEGATE_H
#define TABLEDELEGATE_H

// Qt includes
#include <QStyledItemDelegate>
#include <QPixmap>

// Qt classes
class QPainter;

class TableDelegate : public QStyledItemDelegate
{
    Q_OBJECT

public:
    enum RowColorMode {
        AlternatingRows,
        AlternatingNRows,
        CustomAlternating
    };

    enum Display {
        DrawBackground = Qt::UserRole,
        DrawTopLine
    };

    explicit TableDelegate(QObject *parent,
                           RowColorMode rowColorMode = RowColorMode::AlternatingRows);
    void setAlternationStep(int rows);
    int selectedRow() const;

public Q_SLOTS:
    void setSelectedRow(int row);

protected:
    void paint(QPainter *painter, const QStyleOptionViewItem &option,
               const QModelIndex &index) const override;
    virtual void drawText(QPainter *painter, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const;
    void drawBackground(QPainter *painter, const QStyleOptionViewItem &option,
                        const QModelIndex &index) const;
    void drawTopLine(QPainter *painter, const QStyleOptionViewItem &option) const;

private: // Variables
    RowColorMode m_rowColorMode;
    int m_alternationStep = 2;
    QColor m_topLineColor;
    QBrush m_alternateBackground;
    int m_selectedRow = -1;

};

#endif // TABLEDELEGATE_H
